@@ -3,7 +3,7 @@ package Devel::Platform::Match;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2020-10-08'; # DATE
 our $DIST = 'Devel-Platform-Match'; # DIST
-our $VERSION = '0.001'; # VERSION
+our $VERSION = '0.002'; # VERSION
 
 use 5.010001;
 use strict;
@@ -383,7 +383,18 @@ Devel::Platform::Match - Match platform information with platform specification
 
 =head1 VERSION
 
-This document describes version 0.001 of Devel::Platform::Match (from Perl distribution Devel-Platform-Match), released on 2020-10-08.
+This document describes version 0.002 of Devel::Platform::Match (from Perl distribution Devel-Platform-Match), released on 2020-10-08.
+
+=head1 SYNOPSIS
+
+ use Devel::Platform::Match qw(match_platform parse_platform_spec);
+
+ # assuming we're on an Ubuntu Linux 20.04 64bit
+ my $envres = match_platform("osflag=linux"); # -> [200, "OK", 1]
+ my $envres = match_platform("linux32");      # -> [200, "OK", 0] # linux32 is alias for "osflag=linux archname=x86"; archname doesn't match
+ my $envres = match_platform("win64");        # -> [200, "OK", 0] # win64 is alias for "osflag=Win32 archname=x86_64"; osflag doesn't match
+ my $envres = match_platform("osflag=linux oslabel=~/Debian|Ubuntu|Mint/"); # -> [200, "OK", 1]
+ my $envres = match_platform("osflag=linux, oslabel=~/Debian|Ubuntu|Mint/, osvers >= 21"); # -> [200, "OK", 0] ; # osvers doesn't match
 
 =head1 DESCRIPTION
 
@@ -454,7 +465,7 @@ Examples:
 
 =item * Example #1:
 
- match_platform("osflag=linux", { osflag => "linux", oslabel => "Debian" });
+ match_platform("osflag=linux", { oslabel => "Debian", osflag => "linux" });
 
 Result:
 
